pub async fn pause_run(client: &ControlClient, args: &PauseArgs) -> Result<()>Expand description
lev pause: park a run. The daemon refuses (ok: false) when the run does
not exist or is not in a pausable state (waiting on input, or finished).
pub async fn pause_run(client: &ControlClient, args: &PauseArgs) -> Result<()>lev pause: park a run. The daemon refuses (ok: false) when the run does
not exist or is not in a pausable state (waiting on input, or finished).