pub async fn send_shutdown(client: &ControlClient) -> Result<()>Expand description
Ask the daemon to shut down and report the outcome.
pub async fn send_shutdown(client: &ControlClient) -> Result<()>Ask the daemon to shut down and report the outcome.