pub async fn execute(args: DoctorArgs, daemon: DaemonTarget<'_>) -> Result<()>Expand description
lev doctor. The binary decides what the fourth check gets to talk to; see
DaemonTarget.
pub async fn execute(args: DoctorArgs, daemon: DaemonTarget<'_>) -> Result<()>lev doctor. The binary decides what the fourth check gets to talk to; see
DaemonTarget.