pub fn dedup_name(existing: &[MCPServerConfig], name: &str) -> StringExpand description
A name that does not collide with anything already configured, by appending
-2, -3, … Used when the user chooses to keep both.
pub fn dedup_name(existing: &[MCPServerConfig], name: &str) -> StringA name that does not collide with anything already configured, by appending
-2, -3, … Used when the user chooses to keep both.