pub enum EditTarget {
Credential(usize),
Field(usize),
}Expand description
Where the text being typed goes when it is committed.
Variants
Credential(usize)
The credential of the provider at this index in providers.
Field(usize)
The field at this index of the current step’s fields.