pub fn binary_step(method: &InstallMethod) -> BinaryStepExpand description
The upgrade step for an install method: the commands to run, or the reason there are none.
pub fn binary_step(method: &InstallMethod) -> BinaryStepThe upgrade step for an install method: the commands to run, or the reason there are none.