pub fn plan(args: &UpdateArgs, env: &UpdateEnv) -> UpdatePlanExpand description
Work out everything the command would do, without doing any of it.
pub fn plan(args: &UpdateArgs, env: &UpdateEnv) -> UpdatePlanWork out everything the command would do, without doing any of it.