pub async fn execute(args: ValidateArgs) -> Result<()>Expand description
Run lev validate: check a blueprint and print what is wrong with it.
pub async fn execute(args: ValidateArgs) -> Result<()>Run lev validate: check a blueprint and print what is wrong with it.