pub fn stop_fallback(recorded_pid: Option<u32>) -> StopFallbackExpand description
Decide the fallback for a refused shutdown, given the recorded pid.
pub fn stop_fallback(recorded_pid: Option<u32>) -> StopFallbackDecide the fallback for a refused shutdown, given the recorded pid.