daemon_build_is_stale

Function daemon_build_is_stale 

pub fn daemon_build_is_stale(recorded: Option<&str>) -> bool
Whether a running daemon should be restarted because it is on a different build than this CLI (or recorded no build at all - e.g. it predates this check).