pub async fn handle(h: &SubAgentHandle, tc: &ToolCall) -> StringExpand description
Dispatch one sub-agent tool call, returning the textual result for the model.
pub async fn handle(h: &SubAgentHandle, tc: &ToolCall) -> StringDispatch one sub-agent tool call, returning the textual result for the model.