pub fn markdown_to_text(input: &str, width: u16) -> Text<'static>
Convert a markdown string to ratatui Text for rendering in a Paragraph.
Text
Paragraph
width is used to draw horizontal rules to the correct width.
width