pub fn force_cancel(run_id: &str) -> ForceCancelOutcomeExpand description
Force a run’s on-disk metadata to Cancelled, in the runs dir resolved from
the environment. See force_cancel_in.
pub fn force_cancel(run_id: &str) -> ForceCancelOutcomeForce a run’s on-disk metadata to Cancelled, in the runs dir resolved from
the environment. See force_cancel_in.