pub fn read_context_snapshot(run_id: &str) -> Option<ContextSnapshot>Expand description
Read the context snapshot for a run, if present.
pub fn read_context_snapshot(run_id: &str) -> Option<ContextSnapshot>Read the context snapshot for a run, if present.