pub fn read_stage_context(
run_id: &str,
stage_idx: usize,
) -> Option<ContextSnapshot>Expand description
Read the context snapshot for a specific stage, if present.
pub fn read_stage_context(
run_id: &str,
stage_idx: usize,
) -> Option<ContextSnapshot>Read the context snapshot for a specific stage, if present.