pub fn read_stages_index(run_id: &str) -> Vec<StageRecord>Expand description
Read the stages index for a run, or return an empty vec on any error.
pub fn read_stages_index(run_id: &str) -> Vec<StageRecord>Read the stages index for a run, or return an empty vec on any error.