pub async fn send_list(client: &ControlClient) -> Result<()>Expand description
Query the daemon for its runs and print the formatted listing.
pub async fn send_list(client: &ControlClient) -> Result<()>Query the daemon for its runs and print the formatted listing.