lev validate - Validate an agent blueprint.
Structs
- Blueprint
Summary - The blueprint itself, for a caller that wants to know what it just validated.
- Validate
Args - Arguments for
lev validate. - Validate
Report - What
lev validate --jsonprints.
Functions
- execute
- Run
lev validate: check a blueprint and print what is wrong with it.