pub async fn send_spawn(
client: &ControlClient,
spawn_args: SpawnArgs,
) -> Result<()>Expand description
Send a resolved spawn request to the daemon and report the outcome, printing the new run id on success.
pub async fn send_spawn(
client: &ControlClient,
spawn_args: SpawnArgs,
) -> Result<()>Send a resolved spawn request to the daemon and report the outcome, printing the new run id on success.