markdown_to_text

Function markdown_to_text 

pub fn markdown_to_text(input: &str, width: u16) -> Text<'static>
Convert a markdown string to ratatui Text for rendering in a Paragraph.

width is used to draw horizontal rules to the correct width.